@@ -7,7 +7,7 @@ use warnings;
 
 use Exporter 'import';
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Ref::Util qw[
   is_plain_arrayref is_arrayref
@@ -59,9 +59,9 @@ my %source = (
     spath => { type => Str,       optional => 1 },
     stype => { type => UseDataAs, default  => 'auto' },
     sxfrm => {
-	      # ( Enum [] ) | CoderRef rather than Enum[] | CodeRef for
-	      # Perl < 5.14
-        type => ( Enum [ 'iterate', 'array', 'hash', 'error' ] ) | CodeRef,
+        # ( Enum [] ) | CoderRef rather than Enum[] | CodeRef for
+        # Perl < 5.14
+        type    => ( Enum [ 'iterate', 'array', 'hash', 'error' ] ) | CodeRef,
         default => 'error'
     },
     sxfrm_args => {
@@ -91,7 +91,7 @@ my %Validation = (
     insert => {
         %dest, %length, %offset, %source, %dtype,
         insert => {
-            type => Enum [ 'before', 'after' ],
+            type    => Enum [ 'before', 'after' ],
             default => 'before',
         },
         anchor =>
@@ -102,10 +102,16 @@ my %Validation = (
     replace => {
         %dest, %source,
         replace => {
-            type => Enum [ 'value', 'key', 'auto' ],
+            type    => Enum [ 'value', 'key', 'auto' ],
             default => 'auto',
         },
-
+    },
+    transform => {
+        %dest,
+        callback => {
+            type => CodeRef
+        },
+        callback_data => { type => Any, default => undef }
     },
 );
 
@@ -115,7 +121,7 @@ my %Validator = map {
         params           => $Validation{$_},
         name             => $_,
         name_is_optional => 1,
-      )
+    )
   }
   keys %Validation;
 
@@ -151,7 +157,7 @@ sub edit {
 
     elsif ( $action eq 'splice' ) {
 
-        $src = [ \[] ] if ! defined $src;
+        $src = [ \[] ] if !defined $src;
 
         _splice( $arg{dtype}, $points, $arg{offset}, $arg{length},
             _deref( $_, $arg{stype}, $arg{clone} ) )
@@ -172,6 +178,10 @@ sub edit {
         _delete( $points, $arg{length} );
     }
 
+    elsif ( $action eq 'transform' ) {
+        _transform( $points, $arg{callback}, $arg{callback_data} );
+    }
+
     elsif ( $action eq 'replace' ) {
 
         Data::Edit::Struct::failure::input::src->throw(
@@ -271,7 +281,11 @@ sub _sxfrm {
             for my $point ( @{ $ctx->_search( $spath )->current_points } ) {
 
                 my $attrs = $point->attrs;
-                defined( my $key = defined $attrs->{key} ? $attrs->{key} : $attrs->{idx} )
+                defined(
+                    my $key
+                      = defined $attrs->{key}
+                    ? $attrs->{key}
+                    : $attrs->{idx} )
                   or Data::Edit::Struct::failure::input::src->throw(
                     "source path returned multiple values; unable to convert into hash as element has no `key' or `idx' attribute\n"
                   );
@@ -397,7 +411,9 @@ sub _splice {
 
         my $attrs = $point->can( 'attrs' );
 
-        my $idx = ( ( defined( $attrs ) && $point->$attrs ) ? $point->$attrs : {} )->{idx};
+        my $idx
+          = ( ( defined( $attrs ) && $point->$attrs ) ? $point->$attrs : {} )
+          ->{idx};
 
         my $use = $dtype;
 
@@ -413,12 +429,12 @@ sub _splice {
         }
 
         if ( $use eq 'container' ) {
-            $ref = $point->ref if ! defined $ref;
+            $ref = $point->ref if !defined $ref;
             Data::Edit::Struct::failure::input::dest->throw(
                 "point is not an array reference" )
               unless is_arrayref( $$ref );
 
-            splice( @{ $$ref }, $offset, $length, @$replace );
+            splice( @{$$ref}, $offset, $length, @$replace );
         }
 
         elsif ( $use eq 'element' ) {
@@ -471,7 +487,7 @@ sub _insert {
 
         if ( $use eq 'container' ) {
 
-            $ref = $point->ref if ! defined $ref;
+            $ref = $point->ref if !defined $ref;
 
             if ( is_hashref( $$ref ) ) {
 
@@ -504,7 +520,8 @@ sub _insert {
                 "point is not an array element" )
               unless defined $parent && is_arrayref( $$parent );
 
-            $idx = ( defined $attrs ? $attrs : $point->attrs )->{idx} if ! defined $idx;
+            $idx = ( defined $attrs ? $attrs : $point->attrs )->{idx}
+              if !defined $idx;
 
             _insert_via_splice( $insert, 'index', $pad, $parent, $idx,
                 $offset, $src );
@@ -529,7 +546,7 @@ sub _insert_via_splice {
         $fididx = 0;
     }
     elsif ( $anchor eq 'last' ) {
-        $fididx = $#{ $$rdest };
+        $fididx = $#{$$rdest};
     }
     elsif ( $anchor eq 'index' ) {
         $fididx = $idx;
@@ -544,29 +561,29 @@ sub _insert_via_splice {
     $idx = $offset + $fididx;
 
     # make sure there's enough room.
-    my $maxidx = $#{ $$rdest };
+    my $maxidx = $#{$$rdest};
 
     if ( $insert eq 'before' ) {
 
         if ( $idx < 0 ) {
-            unshift @{ $$rdest }, ( $pad ) x ( -$idx );
+            unshift @{$$rdest}, ( $pad ) x ( -$idx );
             $idx = 0;
         }
 
         elsif ( $idx > $maxidx + 1 ) {
-            push @{ $$rdest }, ( $pad ) x ( $idx - $maxidx - 1 );
+            push @{$$rdest}, ( $pad ) x ( $idx - $maxidx - 1 );
         }
     }
 
     elsif ( $insert eq 'after' ) {
 
         if ( $idx < 0 ) {
-            unshift @{ $$rdest }, ( $pad ) x ( -$idx - 1 ) if $idx < -1;
+            unshift @{$$rdest}, ( $pad ) x ( -$idx - 1 ) if $idx < -1;
             $idx = 0;
         }
 
         elsif ( $idx > $maxidx ) {
-            push @{ $$rdest }, ( $pad ) x ( $idx - $maxidx );
+            push @{$$rdest}, ( $pad ) x ( $idx - $maxidx );
             ++$idx;
         }
 
@@ -632,7 +649,7 @@ sub _replace {
           if $replace eq 'auto';
 
         if ( $replace eq 'value' ) {
-            ${ $point->ref } = ${ $src };
+            ${ $point->ref } = ${$src};
         }
 
         elsif ( $replace eq 'key' ) {
@@ -660,6 +677,17 @@ sub _replace {
     }
 }
 
+#---------------------------------------------------------------------
+
+sub _transform {
+
+    my ( $points, $cb, $cb_data ) = @_;
+
+    for my $point ( @$points ) {
+        $cb->( $point, $cb_data );
+    }
+}
+
 
 1;
 
@@ -673,6 +701,8 @@ sub _replace {
 #   The GNU General Public License, Version 3, June 2007
 #
 
+__END__
+
 =pod
 
 =head1 NAME
@@ -681,7 +711,7 @@ Data::Edit::Struct - Edit a Perl structure addressed with a Data::DPath path
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -735,6 +765,8 @@ The following actions may be performed on the destination structure:
 
 =item * C<replace> - replace array or hash elements (and in the latter case keys)
 
+=item * C<transform> - transform elements
+
 =back
 
 =head2 Elements I<vs.> Containers
@@ -743,7 +775,7 @@ B<Data::Edit::Struct> operates on elements in the destination
 structure by following a L<Data::DPath> path.  For example, if
 
  $src  = { dogs => 'rule' };
- $dest = { bar => [ 2, { cats => 'rule' }, 4 ] };
+ $dest = { bar  => [ 2, { cats => 'rule' }, 4 ] };
 
 then a data path of
 
@@ -826,7 +858,7 @@ callback to perform their own.
 Most of the transformations have to do with multiple values being
 returned by the source path.  For example,
 
- $src  = { foo => [1], bar => [5], baz => [5] };
+ $src   = { foo => [1], bar => [5], baz => [5] };
  $spath = '/*/*[value == 5]';
 
 would result in multiple extracted values:
@@ -911,7 +943,7 @@ The value of the C<sxfrm_args> option.
 
 =head2 Data Copying
 
-By defult, copying of data from the source structure is done
+By default, copying of data from the source structure is done
 I<shallowly>, e.g. references to arrays or hashes are not copied
 recursively.  This may cause problems if further modifications are
 made to the destination structure which may, through references,
@@ -926,8 +958,8 @@ and this edit operation:
 
  edit(
      insert => {
- 	       src  => $src,
- 	       dest => $dest,
+         src  => $src,
+         dest => $dest,
      } );
 
 We get a destination structure that looks like this:
@@ -953,6 +985,8 @@ copy data.
 
 Edit a data structure.  The available actions are discussed below.
 
+=head3 Parameters
+
 Destination structure parameters are:
 
 =over
@@ -1024,9 +1058,11 @@ be cloned.  It should return a I<reference> to the cloned structure.
 
 =back
 
+=head3 Actions
+
 Actions may have additional parameters
 
-=head3 C<pop>
+=head4 C<pop>
 
 Remove one or more elements from the end of an array.  The destination
 structure must be an array. Additional parameters are:
@@ -1039,7 +1075,7 @@ The number of elements to remove.  Defaults to C<1>.
 
 =back
 
-=head3 C<shift>
+=head4 C<shift>
 
 Remove one or more elements from the front of an array.  The
 destination structure must be an array. Additional parameters are:
@@ -1052,7 +1088,7 @@ The number of elements to remove.  Defaults to C<1>.
 
 =back
 
-=head3 C<splice>
+=head4 C<splice>
 
 Perform a L<splice|perlfunc/splice> operation on an array, e.g.
 
@@ -1068,7 +1104,7 @@ option.
 
 A source structure is optional, and may be an array or a hash.
 
-=head3 C<insert>
+=head4 C<insert>
 
 Insert a source structure into the destination structure.  The result
 depends upon whether the point at which to insert is to be treated as
@@ -1105,7 +1141,7 @@ May be C<first> or C<last>.  It defaults to C<first>.
 
 =item C<pad>
 
-If the array must be enlarged to accomodate the specified insertion point, fill the new
+If the array must be enlarged to accommodate the specified insertion point, fill the new
 values with this value.  Defaults to C<undef>.
 
 =item C<insert>
@@ -1120,7 +1156,7 @@ be either C<before> or C<after>.  It defaults to C<before>.
 =item element
 
 The insertion point must be an array value. The source may be either a
-container or an element. The following options are avaliable:
+container or an element. The following options are available:
 
 =over
 
@@ -1130,7 +1166,7 @@ Move the insertion point by this value.
 
 =item C<pad>
 
-If the array must be enlarged to accomodate the specified insertion point, fill the new
+If the array must be enlarged to accommodate the specified insertion point, fill the new
 values with this value.  Defaults to C<undef>.
 
 =item C<insert>
@@ -1142,11 +1178,13 @@ be either C<before> or C<after>.  It defaults to C<before>.
 
 =back
 
-=head2 C<delete>
+=head4 C<delete>
 
-Remove an array or hash value.
+Remove an array or hash value.  If an array, the C<length> option
+specifies the number of elements to remove, starting at that element.
+it defaults to C<1>.
 
-=head2 C<replace>
+=head4 C<replace>
 
 Replace an array or hash element, or a hash key. The source data is
 always treated as an element. It takes the following options:
@@ -1162,6 +1200,48 @@ L<Scalar::Util::refaddr|Scalar::Util/reffadr> will be used.
 
 =back
 
+=head4 C<transform>
+
+Transform an element via a user provided subroutine.  It takes the
+following options:
+
+=over
+
+=item C<callback_data>
+
+Arbitrary data to be passed to the callback.
+
+=item C<callback>
+
+A code reference which will be called for each element.  It is invoked as
+
+  $callback->( $point, $callback_data );
+
+where C<$point> is the L<Data::DPath::Point> object representing the element,
+and C<$data> is the value of the C<callback_data> option.
+
+Here's a silly example showing how to use the element object's
+attributes for a hash element:
+
+ $dest = { a => '1', 'b' => 2 };
+ 
+ edit(
+     transform => {
+         dest     => $dest,
+         dpath    => '/*',
+         callback => sub {
+             my ( $point, $data ) = @_;
+             ${ $point->ref } .= $point->attrs->key;
+         },
+     },
+ );
+
+With the result:
+
+ $dest = { a => "1a", b => "2b" };
+
+=back
+
 =head1 AUTHOR
 
 Diab Jerius <djerius@cpan.org>
@@ -1175,445 +1255,3 @@ This is free software, licensed under:
   The GNU General Public License, Version 3, June 2007
 
 =cut
-
-__END__
-
-
-#pod =head1 SYNOPSIS
-#pod
-#pod # EXAMPLE: ./examples/synopsis.pl
-#pod
-#pod =head1 DESCRIPTION
-#pod
-#pod B<Data::Edit::Struct> provides a high-level interface for editing data
-#pod within complex data structures.  Edit and source points are specified
-#pod via L<Data::DPath> paths.
-#pod
-#pod The I<destination> structure is the structure to be edited.  If data
-#pod are to be inserted into the structure, they are extracted from the
-#pod I<source> structure.  See L</Data Copying> for the copying policy.
-#pod
-#pod The following actions may be performed on the destination structure:
-#pod
-#pod =over
-#pod
-#pod =item  * C<shift> - remove one or more elements from the front of an array
-#pod
-#pod =item  * C<pop> - remove one or more elements from the end of an array
-#pod
-#pod =item  * C<splice> - invoke C<splice> on an array
-#pod
-#pod =item  * C<insert> - insert elements into an array or a hash
-#pod
-#pod =item  * C<delete> - delete array or hash elements
-#pod
-#pod =item  * C<replace> - replace array or hash elements (and in the latter case keys)
-#pod
-#pod =back
-#pod
-#pod =head2 Elements I<vs.> Containers
-#pod
-#pod B<Data::Edit::Struct> operates on elements in the destination
-#pod structure by following a L<Data::DPath> path.  For example, if
-#pod
-#pod # EXAMPLE: ./examples/ex1_0.pl
-#pod
-#pod then a data path of
-#pod
-#pod  /bar/*[0]
-#pod
-#pod identifies the first element in the C<bar> array.  That element may be
-#pod treated either as a I<container> or as an I<element> (this is
-#pod specified by the L</dtype> option).
-#pod
-#pod In the above example, C<< $dest->{bar}[0] >> resolves to a scalar, so
-#pod by default it is treated as an element.  However C<< $dest->{bar[1]}
-#pod >> resolves to a hashref.  When operating on it, should it be treated
-#pod as an opaque object, or as container?  For example,
-#pod
-#pod # EXAMPLE: ./examples/ex1_1.pl
-#pod
-#pod Should C<$src> be inserted I<into> element 2, as in
-#pod
-#pod # COMMAND: perl ./examples/run ex1_0.pl ex1_1.pl  dump_dest.pl
-#pod
-#pod or should it be inserted I<before> element 2 in C<bar>, as in?
-#pod
-#pod # COMMAND: perl ./examples/run ex1_0.pl ex1_2.pl  dump_dest.pl
-#pod
-#pod The first behavior treats it as a I<container>, the second as an
-#pod I<element>.  By default destination paths which resolve to hash or
-#pod array references are treated as B<containers>, so the above code
-#pod generates the first behavior.  To explicitly indicate how a path
-#pod should be treated, use the C<< dtype >> option.  For example,
-#pod
-#pod # EXAMPLE: ./examples/ex1_2.pl
-#pod
-#pod results in
-#pod
-#pod # COMMAND: perl ./examples/run ex1_0.pl ex1_2.pl  dump_dest.pl
-#pod
-#pod Source structures may have the same ambiguity. In the above example,
-#pod note that the I<contents> of the hash in the source path are inserted,
-#pod not the reference itself.  This is because non-blessed references in
-#pod sources are by default considered to be containers, and their contents
-#pod are copied.  To treat a source reference as an opaque element, use the
-#pod L</stype> option to specify it as such:
-#pod
-#pod # EXAMPLE: ./examples/ex1_3.pl
-#pod
-#pod which results in
-#pod
-#pod # COMMAND: perl ./examples/run ex1_0.pl ex1_3.pl  dump_dest.pl
-#pod
-#pod Note that C<dpath> was set to I<element>, otherwise C<edit> would have
-#pod attempted to insert the source hashref (not its contents) into the
-#pod destination hash, which would have failed, as insertion into a hash
-#pod requires a multiple of two elements (i.e., C<< $key, $value >>).
-#pod
-#pod =head2 Source Transformations
-#pod
-#pod Data extracted from the source structure may undergo transformations
-#pod prior to being inserted into the destination structure.  There are
-#pod several predefined transformations and the caller may specify a
-#pod callback to perform their own.
-#pod
-#pod Most of the transformations have to do with multiple values being
-#pod returned by the source path.  For example,
-#pod
-#pod # EXAMPLE: ./examples/sxfrm1_0.pl
-#pod
-#pod would result in multiple extracted values:
-#pod
-#pod # COMMAND: perl ./examples/run examples/sxfrm1_0.pl  examples/sxfrm1_1.pl
-#pod
-#pod By default multiple values are not allowed, but a source
-#pod transformation (specified by the C<sxfrm> option ) may be used to
-#pod change that behavior.  The provided transforms are:
-#pod
-#pod =over
-#pod
-#pod =item C<array>
-#pod
-#pod The values are assembled into an array.  The C<stype>
-#pod parameter is used to determine whether that array is treated as a
-#pod container or an element.
-#pod
-#pod =item C<hash>
-#pod
-#pod The items are assembled into a hash.  The C<stype> parameter is used
-#pod to determine whether that hash is treated as a container or an
-#pod element.  Keys are derived from the data:
-#pod
-#pod =over
-#pod
-#pod =item * Keys for hash values will be their hash keys
-#pod
-#pod =item * Keys for array values will be their array indices
-#pod
-#pod =back
-#pod
-#pod If there is a I<single> value, a hash key may be specified via the
-#pod C<key> option to the C<sxfrm_args> option.
-#pod
-#pod =item C<iterate>
-#pod
-#pod The edit action is applied independently to each source value in turn.
-#pod
-#pod
-#pod =item I<coderef>
-#pod
-#pod If C<sxfrm> is a code reference, it will be called to generate the
-#pod source values.  See L</Source Callbacks> for more information.
-#pod
-#pod =back
-#pod
-#pod
-#pod =head2 Source Callbacks
-#pod
-#pod If the C<sxfrm> option is a code reference, it is called to generate
-#pod the source values.  It must return an array which contains I<references>
-#pod to the values (even if they are already references).  For example,
-#pod to return a hash:
-#pod
-#pod   my %src = ( foo => 1 );
-#pod   return [ \\%hash ];
-#pod
-#pod It is called with the arguments
-#pod
-#pod =over
-#pod
-#pod =item C<$ctx>
-#pod
-#pod
-#pod A L</Data::DPath::Context> object representing the source structure.
-#pod
-#pod =item C<$spath>
-#pod
-#pod The source path.  Unless otherwise specified, this defaults to C</>,
-#pod I<except> when the source is not a plain array or plain
-#pod hash, in which case the source is embedded in an array, and C<spath> is set to C</*[0]>.
-#pod
-#pod This is because L</Data::DPath> requires a container to be at the root
-#pod of the source structure, and anything other than a plain array or hash
-#pod is most likely a blessed object or a scalar, both of which should be
-#pod treated as elements.
-#pod
-#pod =item C<$args>
-#pod
-#pod The value of the C<sxfrm_args> option.
-#pod
-#pod =back
-#pod
-#pod =head2 Data Copying
-#pod
-#pod By defult, copying of data from the source structure is done
-#pod I<shallowly>, e.g. references to arrays or hashes are not copied
-#pod recursively.  This may cause problems if further modifications are
-#pod made to the destination structure which may, through references,
-#pod alter the source structure.
-#pod
-#pod For example, given the following input structures:
-#pod
-#pod # EXAMPLE: ./examples/copy1_0.pl
-#pod
-#pod and this edit operation:
-#pod
-#pod # EXAMPLE: ./examples/copy1_1.pl
-#pod
-#pod We get a destination structure that looks like this:
-#pod
-#pod # COMMAND: perl ./examples/run copy1_0.pl copy1_1.pl  dump_dest.pl
-#pod
-#pod But if later we change C<$dest>,
-#pod
-#pod # EXAMPLE: ./examples/copy1_2.pl
-#pod
-#pod the source structure is also changed:
-#pod
-#pod # COMMAND: perl ./examples/run copy1_0.pl copy1_1.pl  copy1_2.pl dump_src.pl
-#pod
-#pod To avoid this possible problem, C<Data::Edit::Struct> can be passed
-#pod the L<< C<clone>|/clone >> option, which will instruct it how to
-#pod copy data.
-#pod
-#pod
-#pod =head1 SUBROUTINES
-#pod
-#pod =head2  edit ( $action, $params )
-#pod
-#pod Edit a data structure.  The available actions are discussed below.
-#pod
-#pod Destination structure parameters are:
-#pod
-#pod =over
-#pod
-#pod =item C<dest>
-#pod
-#pod A reference to a structure or a L<< Data::DPath::Context >> object.
-#pod
-#pod =item C<dpath>
-#pod
-#pod A string representing the data path. This may result in multiple
-#pod extracted values from the structure; the action will be applied to
-#pod each in turn.
-#pod
-#pod =item C<dtype>
-#pod
-#pod May be C<auto>, C<element> or C<container>, to treat the extracted
-#pod values either as elements or containers.  If C<auto>, non-blessed
-#pod arrays and hashes are treated as containers.
-#pod
-#pod =back
-#pod
-#pod Some actions require a source structure; parameters related
-#pod to that are:
-#pod
-#pod =over
-#pod
-#pod =item C<src>
-#pod
-#pod A reference to a structure or a L<Data::DPath::Context> object.
-#pod
-#pod =item C<spath>
-#pod
-#pod A string representing the source path. This may result in multiple
-#pod extracted values from the structure; the C<sxfrm> option provides
-#pod the context for how to interpret these values.
-#pod
-#pod =item C<stype>
-#pod
-#pod May be C<auto>, C<element> or C<container>, to treat the extracted
-#pod values either as elements or containers.  If C<auto>, non-blessed
-#pod arrays and hashes are treated as containers.
-#pod
-#pod =item C<sxfrm>
-#pod
-#pod A transformation to be applied to the data extracted from the
-#pod source. The available values are
-#pod
-#pod =over
-#pod
-#pod =item C<array>
-#pod
-#pod =item C<hash>
-#pod
-#pod =item C<iterate>
-#pod
-#pod =item I<coderef>
-#pod
-#pod =back
-#pod
-#pod See L</Source Transformations> for more information.
-#pod
-#pod =item C<clone>
-#pod
-#pod This may be a boolean or a code reference.  If a boolean, and true,
-#pod L<Storable/dclone> is used to clone the source structure.  If set to a
-#pod code reference, it is called with a I<reference> to the structure to
-#pod be cloned.  It should return a I<reference> to the cloned structure.
-#pod
-#pod =back
-#pod
-#pod Actions may have additional parameters
-#pod
-#pod =head3 C<pop>
-#pod
-#pod Remove one or more elements from the end of an array.  The destination
-#pod structure must be an array. Additional parameters are:
-#pod
-#pod
-#pod =over
-#pod
-#pod =item C<length>
-#pod
-#pod The number of elements to remove.  Defaults to C<1>.
-#pod
-#pod =back
-#pod
-#pod
-#pod =head3 C<shift>
-#pod
-#pod Remove one or more elements from the front of an array.  The
-#pod destination structure must be an array. Additional parameters are:
-#pod
-#pod
-#pod =over
-#pod
-#pod =item C<length>
-#pod
-#pod The number of elements to remove.  Defaults to C<1>.
-#pod
-#pod =back
-#pod
-#pod
-#pod =head3 C<splice>
-#pod
-#pod Perform a L<splice|perlfunc/splice> operation on an array, e.g.
-#pod
-#pod   splice( @$dest, $offset, $length, @$src );
-#pod
-#pod The C<$offset> and C<$length> parameters are provided by the C<offset>
-#pod and C<length> options.
-#pod
-#pod The destination structure may be an array or an array element.  In the
-#pod latter case, the actual offset passed to splice is the sum of the
-#pod index of the array element and the value provided by the C<offset>
-#pod option.
-#pod
-#pod A source structure is optional, and may be an array or a hash.
-#pod
-#pod =head3 C<insert>
-#pod
-#pod Insert a source structure into the destination structure.  The result
-#pod depends upon whether the point at which to insert is to be treated as
-#pod a container or an element.
-#pod
-#pod =over
-#pod
-#pod =item container
-#pod
-#pod =over
-#pod
-#pod =item Hash
-#pod
-#pod If the container is a hash, the source must be a container (either
-#pod array or hash), and must contain an even number of elements.  Each
-#pod sequential pair of values is treated as a key, value pair.
-#pod
-#pod =item Array
-#pod
-#pod If the container is an array, the source may be either a container or
-#pod an element. The following options are available:
-#pod
-#pod =over
-#pod
-#pod =item C<offset>
-#pod
-#pod The offset into the array of the insertion point.  Defaults to C<0>.
-#pod See L</anchor>.
-#pod
-#pod =item C<anchor>
-#pod
-#pod Indicates which end of the array the C<offset> parameter is relative to.
-#pod May be C<first> or C<last>.  It defaults to C<first>.
-#pod
-#pod =item C<pad>
-#pod
-#pod If the array must be enlarged to accomodate the specified insertion point, fill the new
-#pod values with this value.  Defaults to C<undef>.
-#pod
-#pod =item C<insert>
-#pod
-#pod Indicates which side of the insertion point data will be inserted. May
-#pod be either C<before> or C<after>.  It defaults to C<before>.
-#pod
-#pod =back
-#pod
-#pod =back
-#pod
-#pod =item element
-#pod
-#pod The insertion point must be an array value. The source may be either a
-#pod container or an element. The following options are avaliable:
-#pod
-#pod =over
-#pod
-#pod =item C<offset>
-#pod
-#pod Move the insertion point by this value.
-#pod
-#pod =item C<pad>
-#pod
-#pod If the array must be enlarged to accomodate the specified insertion point, fill the new
-#pod values with this value.  Defaults to C<undef>.
-#pod
-#pod =item C<insert>
-#pod
-#pod Indicates which side of the insertion point data will be inserted. May
-#pod be either C<before> or C<after>.  It defaults to C<before>.
-#pod
-#pod =back
-#pod
-#pod =back
-#pod
-#pod =head2 C<delete>
-#pod
-#pod Remove an array or hash value.
-#pod
-#pod =head2 C<replace>
-#pod
-#pod Replace an array or hash element, or a hash key. The source data is
-#pod always treated as an element. It takes the following options:
-#pod
-#pod =over
-#pod
-#pod
-#pod =item C<replace>
-#pod
-#pod Indicates which part of a hash element to replace, either C<key> or
-#pod C<value>.  Defaults to C<value>.  If replacing the key and the source
-#pod value is a reference, the value returned by
-#pod L<Scalar::Util::refaddr|Scalar::Util/reffadr> will be used.
-#pod
-#pod =back
